@@ -109,16 +109,20 @@ class table:
 
         if AutoInsert:
             lol = True
+            if not ef.isUncertain(*self.data.columns[0:2]):
+                self.data.insert(1, ef.delt(
+                    self.data.columns[0]), [0 for i in range(len(self.data))])
+            
             while lol:
                 lol = False
-                for i in range(len(self.data.columns) - 1):
-                    if not ef.isUncertain(self.data.columns[i]) and\
-                       not ef.isUncertain(self.data.columns[i + 1]):
+                for i in range(1, len(self.data.columns) - 1):
+                    if not ef.isUncertain(*self.data.columns[i:i+2]) and\
+                       not ef.isUncertain(*self.data.columns[i-1:i+1]):
                         self.data.insert(i + 1, ef.delt(self.data.columns[i]),
                                          [0 for i in range(len(self.data))])
                         lol = True
-
-            if not ef.isUncertain(self.data.columns[-1]):
+                        pass
+            if not ef.isUncertain(*self.data.columns[-2:]):
                 self.data.insert(len(self.data.columns), ef.delt(
                     self.data.columns[-1]), [0 for i in range(len(self.data))])
         self.data.columns = list(map(str, self.data.columns))
@@ -391,7 +395,8 @@ class table:
         self.data.insert(index*2, name, dt[name], False)
         self.data.insert(index*2+1, ef.delt(name), dt[ef.delt(name)], False)
 
-    def plot(self, xn, yn, fig_ax=None, **kwargs):
+    def plot(self, xn, yn, fig_ax=None, polar=False, NoErrorBar=False,
+             **kwargs):
         if fig_ax is None:
             fig_ax = plt.figure(), plt.gca()
         fig, ax = fig_ax
@@ -401,17 +406,19 @@ class table:
             dt.newCol(xn, xn)
         if yn not in self.data.columns:
             dt.newCol(yn, yn)
-        if sum(dt[ef.delt(xn)]) == sum(dt[ef.delt(yn)]) == 0:
+        if sum(dt[ef.delt(xn)]) == sum(dt[ef.delt(yn)]) == 0 or NoErrorBar:
             ax.plot(*dt[[xn, yn]].T, ".", **kwargs)
         else:
             ax.errorbar(*dt[[xn, yn, ef.delt(yn), ef.delt(xn)]].T, ".",
                         **kwargs)
         ax.set_xlabel(ef.ax_name(dt, xn))
         ax.set_ylabel(ef.ax_name(dt, yn))
-        # plt.legend()
+        # plt.legend(
+        
+
 
     def fit(self, func, xn, yn, fig_ax=None, show=True, p0=None, maxfev=1000,
-            fit_label='fit', fit_color=None,**kwargs):
+            fit_label='fit', fit_color=None, **kwargs):
         """\n
 
         return optimal parameters of a function fitted on data
@@ -443,7 +450,9 @@ class table:
         dt.renameCols(noms[1:])
         lines = inspect.getsourcelines(func)
 
-
+        polar = False
+        if 'polar' in kwargs:
+            polar = kwargs['polar']
         if len(lines) == 2 and fit_label == 'fit':
             expr = sp.sympify(ef.preSymp(lines[0][-1].replace('return ', '')))
             fit_label = "$"+sp.latex(expr)+"$"
@@ -486,7 +495,7 @@ class table:
                     outCol.append("$" + s + "$")
                 else:
                     outCol.append(
-                        "$" + ef.precisionStr(val, d)  + " \\pm " + "{:.1g}$"
+                        "$" + ef.precisionStr(val, d) + " \\pm " + "{:.1g}$"
                         .format(ef.roundUp(self.data[ef.delt(col)][x]))
                         )
             out[col] = outCol
@@ -497,7 +506,6 @@ class table:
         return(out)
 
 
-
 def defVal(vals):
     for i in vals:
         a = vals[i].split(" ")
